# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0] - 2019-04-08
### Added
- Initialize Django module for one-off management commands [\#2](https://github.com/azavea/django-ecsmanage/pull/2).

[Unreleased]: https://github.com/azavea/django-ecsmanage/compare/0.1.0...HEAD
[0.1.0]: https://github.com/azavea/django-ecsmanage/releases/tag/0.1.0
